@@ -118,7 +118,6 @@ enum raw1394_modify_mode {
 	RAW1394_MODIFY_FREE
 };
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -328,6 +327,25 @@ void raw1394_iso_stop(raw1394handle_t handle);
  **/
 void raw1394_iso_shutdown(raw1394handle_t handle);
 
+/**
+ * raw1394_get_cycle_timer - get the current value of the cycle timer
+ * @handle: libraw1394 handle
+ * @cycle_timer: buffer for Isochronous Cycle Timer
+ * @local_time: buffer for local system time in microseconds since Epoch
+ *
+ * Simultaneously reads the cycle timer register together with the system clock.
+ *
+ * Format of @cycle_timer, from MSB to LSB: 7 bits cycleSeconds (seconds, or
+ * number of cycleCount rollovers), 13 bits cycleCount (isochronous cycles, or
+ * cycleOffset rollovers), 12 bits cycleOffset (24.576 MHz clock ticks, not
+ * provided on some hardware). The union of cycleSeconds and cycleCount is the
+ * current cycle number. The nominal duration of a cycle is 125 microseconds.
+ *
+ * Returns: the error code of the ioctl, or 0 if successful.
+ **/
+int raw1394_read_cycle_timer(raw1394handle_t handle,
+                             u_int32_t *cycle_timer, u_int64_t *local_time);
+
 typedef int raw1394_errcode_t;
 #define raw1394_make_errcode(ack, rcode) (((ack) << 16) | rcode)
 #define raw1394_internal_err(errcode) ((errcode) < 0)
@@ -380,9 +398,14 @@ int raw1394_errcode_to_errno(raw1394_errcode_t errcode);
  * processes.  It is allowed to create and use multiple handles, however.  Use
  * one handle per thread which needs it in the multithreaded case.
  *
+ * The default device node is /dev/raw1394, but one can override the default
+ * by setting environment variable RAW1394DEV. However, if RAW1394DEV points to
+ * a non-existant or invalid device node, then it also attempts to open the
+ * default device node.
+ *
  * Returns: the created handle or %NULL when initialization fails. In the latter
- * case errno either contains some OS specific error code or %0 if the error is
- * that libraw1394 and raw1394 don't support each other's protocol versions.
+ * case errno either contains some OS specific error code or EPROTO if
+ * libraw1394 and raw1394 don't support each other's protocol versions.
  **/
 raw1394handle_t raw1394_new_handle(void);
 
@@ -406,6 +429,11 @@ void raw1394_destroy_handle(raw1394handle_t handle);
  * command-line programs that already know what port they want. If
  * raw1394_set_port() returns ESTALE, retries automatically.
  *
+ * The default device node is /dev/raw1394, but one can override the default
+ * by setting environment variable RAW1394DEV. However, if RAW1394DEV points to
+ * a non-existant or invalid device node, then it also attempts to open the
+ * default device node.
+ *
  * Returns: the new handle on success or NULL on failure
  **/
 raw1394handle_t raw1394_new_handle_on_port(int port);
@@ -1124,7 +1152,7 @@ const char *raw1394_get_libversion(void);
  * raw1394_update_config_rom - updates the configuration ROM of a host
  * @handle: libraw1394 handle
  * @new_rom: a pointer to the new ROM image
- * @size: the size of the new ROM image in quadlets
+ * @size: the size of the new ROM image in bytes
  * @rom_version: the version numer of the current version, not the new
  *
  * @rom_version must be the current
